/**
 * Copyright (C) 2011 Linutop SAS <http://www.linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <config.h>

#include <unistd.h>
#include <sys/types.h>

#include <libxfce4util/libxfce4util.h>
#include <gtk/gtk.h>

#include "libxfcegui4.h"

#include "locksetup.h"

LockItems items;

GtkWidget *
build_iface ()
{
    GtkWidget *d;
    GtkWidget *vbox, *frame;
    GtkWidget *btn;
    GtkWidget *heading;

    d = gtk_dialog_new_with_buttons (_("Lock Mode Security Setup"),
                                     NULL,
                                     0,
                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                     GTK_STOCK_OK, GTK_RESPONSE_OK,
                                     NULL);

    heading = xfce_heading_new ();
    xfce_heading_set_title (XFCE_HEADING (heading),
                            _("Lock Mode Security Setup"));
    xfce_heading_set_icon_name (XFCE_HEADING (heading),
                                "linutop-lock");
    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox), heading, FALSE, FALSE, 0);

    vbox = gtk_vbox_new (TRUE, 0);
    frame = xfce_framebox_new (NULL, TRUE);
    xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox), frame, TRUE, TRUE, 0);

    btn = gtk_check_button_new_with_label (_("Disable all keyboard shortcuts"));
    attach_toggle_to_boolean (btn, &items.no_kbd_shortcut);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Auto log the user"));
    attach_toggle_to_boolean (btn, &items.autolog);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Remove the log out button"));
    attach_toggle_to_boolean (btn, &items.no_logout);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Disable the shutdown/reboot buttons"));
    attach_toggle_to_boolean (btn, &items.no_shutdown);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Remove the startup menu"));
    attach_toggle_to_boolean (btn, &items.no_menu);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Forbid applications to open/save files"));
    attach_toggle_to_boolean (btn, &items.no_open_save);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Disable the contextual menu on icons"));
    attach_toggle_to_boolean (btn, &items.no_icons_menu);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Disable icons and menu on the desktop"));
    attach_toggle_to_boolean (btn, &items.no_desktop);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Add a launcher for the setup on the desktop"));
    attach_toggle_to_boolean (btn, &items.lconfeditor_icon);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Allow to start the setup using ctrl+alt+shift+S"));
    attach_toggle_to_boolean (btn, &items.lconfeditor_shortcut);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    btn = gtk_check_button_new_with_label (_("Disable automounting of external devices"));
    attach_toggle_to_boolean (btn, &items.no_automount);
    gtk_box_pack_start (GTK_BOX (vbox), btn, FALSE, FALSE, 0);

    gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (d)->vbox));

    return d;
}

int
main (int argc, gchar **argv)
{
    GtkWidget *d;

    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");

    gtk_init (&argc, &argv);

    if (getuid () != 0) {
        d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                GTK_MESSAGE_WARNING,
                                GTK_BUTTONS_OK,
                                _("You don't appear to be root. Exiting."));
        gtk_dialog_run (GTK_DIALOG (d));
        return (1);
    }

    gtk_window_set_default_icon_from_file (PIXMAPSDIR "/linutop-lock.png", NULL);

    read_config (&items);
    d = build_iface ();

    g_object_set (gtk_settings_get_default (),
                  "gtk-button-images", TRUE, NULL);

    if (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_OK)
    {
        save_config (&items);
    }

    gtk_widget_destroy (d);

    return 0;
}
